@@ -5,8 +5,10 @@ from cryptomodel.operations import OPERATIONS
 
 class user_settings(Document):
     meta = {'strict': False}
-    userId = IntField()
+    user_id = IntField()
     preferred_currency = StringField()
+    source_id = ObjectIdField()
+    operation = StringField(choices=OPERATIONS.choices())
 
 
 class user_notification(Document):
@@ -37,6 +39,19 @@ class user_transaction(Document):
     currency = StringField()
     source_id = ObjectIdField()
     operation = StringField(choices=OPERATIONS.choices())
+    is_valid = BooleanField(default=True)
+    invalid_reason = StringField(default="")
+
+    def validate_symbol(self, symbols):
+        if symbols is None:
+            self.is_valid = True
+            self.invalid_reason = ""
+        if self.symbol not in symbols:
+            self.is_valid = False
+            self.invalid_reason = "symbol does not exist in list value:" + self.symbol
+        return self.is_valid
+
+
 
 
 class user_channel(Document):
@@ -47,6 +62,6 @@ class user_channel(Document):
     user_email = StringField()
     source_id = ObjectIdField()
     operation = StringField(choices=OPERATIONS.choices())
+
     def set_token(self):
         self.token = get_password(self.notification_type, 'token')
-
